﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.Controls;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.DataPresenter.Events;
using Infragistics.Windows.Editors;
using MorganStanley.Taser.Common.General;
using MorganStanley.Taser.Common.Limits;
using MorganStanley.Taser.Models.Views.Approvals.LimitMonitor;
using MorganStanley.Taser.Views.Views.Approvals.LimitMonitor.LimitTypeGrid;

namespace MorganStanley.Taser.Views.Views.Approvals.LimitMonitor.LimitSetupView.LimitTypeGrid
{
  /// <summary>
  /// Interaction logic for LimitMonitorDetailSetupGrid.xaml
  /// </summary>
  public partial class LimitMonitorDetailSetupGrid : UserControl
  {
    public LimitMonitorDetailSetupGrid()
    {
      InitializeComponent();
      _grid.DataContextChanged += _grid_DataContextChanged;
      if (_grid.FieldLayouts.Count == 0)
        _grid.FieldLayouts.Add(new FieldLayout());
      _grid.FieldLayouts[0].Settings.AutoGenerateFields = false;
      _grid.FieldLayouts[0].Settings.AutoArrangeCells = AutoArrangeCells.Never;
      _grid.FieldLayouts[0].Settings.DataRecordCellAreaStyle = (Style)this.Resources["_dataRecordCellArea"];
      _grid.FieldLayouts[0].Settings.DataRecordPresenterStyle = (Style)this.Resources["_dataRecordPresenter"];
      _grid.FieldSettings.CellClickAction = CellClickAction.SelectCell;
      _grid.CellUpdated += _grid_CellUpdated;
      _grid.FieldLayoutSettings.AllowDelete = true;
      _grid.FieldSettings.CollapseWhenEmpty = true;
      _grid.RecordsDeleting += _grid_RecordsDeleting;
      _grid.RecordsDeleted += _grid_RecordsDeleted;
      //contextMenu = (ContextMenu)this.FindResource("_headerCM");
    }

    void _grid_RecordsDeleted(object sender, RecordsDeletedEventArgs e)
    {
      if (!IsTemplate)
      {
        LimitMonitorDetailSetupModel.LimitSetups = _deletingRecords;
        LimitMonitorDetailSetupModel.ContextDeleteSetupCommand.Execute();
        _deletingRecords = null;
      }
    }

    private List<LimitSetup> _deletingRecords;
    void _grid_RecordsDeleting(object sender, RecordsDeletingEventArgs e)
    {
      if (!IsTemplate)
      {
        _deletingRecords = new List<LimitSetup>();
        foreach (DataRecord record in e.Records)
        {
          LimitMonitorSetupRecordPresenter limitMonitorSetupRecordPresenter =
            record.DataItem as LimitMonitorSetupRecordPresenter;
          if (limitMonitorSetupRecordPresenter != null)
            _deletingRecords.AddRange(limitMonitorSetupRecordPresenter.LimitSetups);
        }
      }
    }

    private IList<LimitSetup> _updatedLimitSetups;

    public IList<LimitSetup> UpdatedLimitSetups
    {
      get { return _updatedLimitSetups; }
      set { _updatedLimitSetups = value; }
    }

    void ChangeColorOnCellValueChange(XamCurrencyEditor currencyEditor, LimitSetup limitSetup)
    {
      if (currencyEditor != null)
      {
        currencyEditor.Foreground = Brushes.Green;
        currencyEditor.FontWeight = FontWeights.Bold;
        if (!_updatedLimitSetups.Contains(limitSetup))
          _updatedLimitSetups.Add(limitSetup);
      }
    }

    void _grid_CellUpdated(object sender, Infragistics.Windows.DataPresenter.Events.CellUpdatedEventArgs e)
    {
      CellValuePresenter cellValuePresenter = CellValuePresenter.FromCell(e.Cell);
      XamCurrencyEditor currencyEditor = cellValuePresenter.FindChild<XamCurrencyEditor>("_numberEditor");
      if (_updatedLimitSetups == null)
        _updatedLimitSetups = new List<LimitSetup>();
      if (e.Cell.Tag != null && e.Cell.Tag is LimitSetup)
      {
        LimitSetup limitSetup = e.Cell.Tag as LimitSetup;
        double amount;
        if (e.Cell.Value != null && limitSetup.Definition.LimitSpecified)
        {
          if (double.TryParse(e.Cell.Value.ToString(), out amount))
          {
            limitSetup.Definition.Limit = new Money(amount, limitSetup.Definition.Limit.Currency);
            ChangeColorOnCellValueChange(currencyEditor, limitSetup);
          }
        }
      }
      else if (e.Record.DataItem is LimitMonitorSetupRecordPresenter)
      {
        LimitSetupConvertor limitSetupConvertor = e.Field.Converter as LimitSetupConvertor;
        LimitMonitorSetupRecordPresenter limitMonitorSetupRecordPresenter = e.Record.DataItem as LimitMonitorSetupRecordPresenter;
        if (limitSetupConvertor != null)
        {
          if (limitSetupConvertor.IsNet)
          {
            foreach (LimitSetup limitSetup in limitMonitorSetupRecordPresenter.LimitSetups_Net)
            {
              if (limitSetup.Definition.Maturity.ToString() == limitSetupConvertor.Maturity)
              {
                double amount;
                if (e.Cell.Value != null && limitSetup.Definition.LimitSpecified)
                {
                  if (double.TryParse(e.Cell.Value.ToString(), out amount))
                  {
                    limitSetup.Definition.Limit = new Money(amount, limitSetup.Definition.Limit.Currency);
                    e.Cell.Tag = limitSetup;
                    ChangeColorOnCellValueChange(currencyEditor, limitSetup);
                  }
                }
              }
            }
          }
          else
          {
            foreach (LimitSetup limitSetup in limitMonitorSetupRecordPresenter.LimitSetups_Gross)
            {
              if (limitSetup.Definition.Maturity.ToString() == limitSetupConvertor.Maturity)
              {
                double amount;
                if (e.Cell.Value != null && limitSetup.Definition.LimitSpecified)
                {
                  if (double.TryParse(e.Cell.Value.ToString(), out amount))
                  {
                    limitSetup.Definition.Limit = new Money(amount, limitSetup.Definition.Limit.Currency);
                    e.Cell.Tag = limitSetup;
                    ChangeColorOnCellValueChange(currencyEditor, limitSetup);
                  }
                }
              }
            }
          }

        }
      }
    }

    public bool IsTemplate { get; set; }

    private LimitMonitorDetailSetupModel _limitMonitorDetailSetupModel;

    public LimitMonitorDetailSetupModel LimitMonitorDetailSetupModel
    {
      get { return _limitMonitorDetailSetupModel; }
    }

    void _grid_DataContextChanged(object sender, DependencyPropertyChangedEventArgs e)
    {
      UpdatedLimitSetups = null;
      if (e.NewValue is LimitMonitorDetailSetupModel)
      {
        _grid.FieldLayouts[0].Fields.Clear();
        _limitMonitorDetailSetupModel = e.NewValue as LimitMonitorDetailSetupModel;

        LimitMonitorSetupRecordPresenterFactory limitMonitorSetupRecordPresenterFactory = new LimitMonitorSetupRecordPresenterFactory(_limitMonitorDetailSetupModel.Items);
        LimitMonitorSetupRecordPresenterCollection = limitMonitorSetupRecordPresenterFactory.GenerateRecords();

        Field field = new Field();
        field.Settings.LabelTextAlignment = TextAlignment.Center;
        field.Name = "ProductTypesAsString";
        field.Label = "Product Types";
        field.Row = 0;
        field.Column = _grid.FieldLayouts[0].Fields.Count;
        field.RowSpan = 2;
        field.Settings.LabelTextAlignment = TextAlignment.Center;
        field.Settings.CellValuePresenterStyle = (Style)this.Resources["_visiblerHeaderRowField"];
        field.Width = FieldLength.Auto;
        //field.Converter = new LimitDetailConvertor();
        //field.ConverterParameter = limitDetail.ProductTypes;
        //field.BindingPath = new PropertyPath(limitDetail.Currency);
        _grid.FieldLayouts[0].Fields.Add(field);


        Field currencyField = new Field();
        currencyField.Settings.LabelTextAlignment = TextAlignment.Center;
        currencyField.Name = "Currency";
        currencyField.RowSpan = 2;
        currencyField.Column = _grid.FieldLayouts[0].Fields.Count;
        currencyField.Row = 0;
        currencyField.Settings.LabelTextAlignment = TextAlignment.Center;
        currencyField.Settings.CellValuePresenterStyle = (Style)this.Resources["_visiblerHeaderRowField"];
        currencyField.Width = FieldLength.Auto;
        
        //currencyField.Settings.AutoSizeOptions = FieldAutoSizeOptions.All;
        //currencyField.BindingPath = new PropertyPath(limitDetail.Currency);
        //currencyField.Binding = new Binding("Currency");
        currencyField.Converter = new LimitDetailCurrencyConvertor();
        //currencyField.ConverterParameter = limitDetail.Currency;
        _grid.FieldLayouts[0].Fields.Add(currencyField);
        _grid.FieldLayouts[0].SortedFields.Add(new FieldSortDescription("Currency", ListSortDirection.Ascending, false));
        //_grid.FieldLayouts[0].Settings.AutoGenerateFields = true;

        IList<LimitMaturity> limitMaturities = new List<LimitMaturity>();
        foreach (LimitMonitorSetupRecordPresenter limitMonitorSetupRecordPresenter in LimitMonitorSetupRecordPresenterCollection)
        {
          if (limitMaturities.Count < limitMonitorSetupRecordPresenter.LimitMaturity.Count)
            limitMaturities = limitMonitorSetupRecordPresenter.LimitMaturity;
        }

        IDictionary<string, IList<bool>> maturityNetGross = new Dictionary<string, IList<bool>>();

        foreach (LimitSetup limitSetup in _limitMonitorDetailSetupModel.Items)
        {
          if (limitSetup.Definition.LimitSpecified)
          {
            if (!maturityNetGross.ContainsKey(limitSetup.Definition.Maturity.ToString()))
            {
              maturityNetGross.Add(limitSetup.Definition.Maturity.ToString(), new List<bool>());
              //maturityNetGross[limitSetup.Definition.Maturity.ToString()].Add(limitSetup.Definition.Net);
            }
            //else
            {
              if (!maturityNetGross[limitSetup.Definition.Maturity.ToString()].Contains(limitSetup.Definition.Net))
                maturityNetGross[limitSetup.Definition.Maturity.ToString()].Add(limitSetup.Definition.Net);
            }
          }
        }

        foreach (KeyValuePair<string, IList<bool>> keyValuePair in maturityNetGross)
        {
          //if (string.IsNullOrEmpty(keyValuePair.Value[0].Definition.Maturity.ToString()) && allMatPresent)
          //  continue;
          UnboundField headerField = new UnboundField();
          headerField.Settings.LabelTextAlignment = TextAlignment.Center;
          headerField.Label = string.IsNullOrEmpty(keyValuePair.Key) ? "All Maturities" : keyValuePair.Key;
          headerField.Name = headerField.Label.ToString();
          headerField.Column = _grid.FieldLayouts[0].Fields.Count;
          headerField.Row = 0;
          headerField.ColumnSpan = 2;
          headerField.Settings.CellValuePresenterStyle = (Style)this.Resources["_hiddenHeaderRowField"];
          headerField.Settings.CellMaxHeight = 0;
          headerField.Settings.AllowEdit = true;
          //headerField.Settings.AutoSizeOptions = FieldAutoSizeOptions.All;
          _grid.FieldLayouts[0].Fields.Add(headerField);
          IList<Field> fields = new List<Field>();
          for (int i = 0; i < keyValuePair.Value.Count; i++)
          {
            //LimitUsage limitUsage = keyValuePair.Value[i];
            //string isNet = keyValuePair.Value[i];// limitUsage.Definition.Net ? "Net" : "Gross";

            UnboundField unboundField = new UnboundField();
            unboundField.Settings.LabelTextAlignment = TextAlignment.Center;
            unboundField.Label = (keyValuePair.Value[i]) ? "Net" : "Gross";
            unboundField.Settings.CellValuePresenterStyle = (Style)this.Resources["_visiblerHeaderRowFieldLeft"];
            unboundField.Converter = new LimitSetupConvertor(keyValuePair.Key, keyValuePair.Value[i]);
            unboundField.Tag = headerField;
            unboundField.Column = headerField.Column + i;
            unboundField.Row = 1;
            unboundField.Settings.AllowEdit = true;
            unboundField.Name = headerField.Name + "_" + unboundField.Label;
            _grid.FieldLayouts[0].Fields.Add(unboundField);
            fields.Add(unboundField);
          }
          headerField.Tag = fields;
        }

        foreach (Field fieldtemplate in _grid.FieldLayouts[0].Fields)
        {
          if (!fieldtemplate.Name.Equals("ProductTypesAsString") && !fieldtemplate.Name.Equals("Currency"))
            fieldtemplate.Settings.LabelPresenterStyle = (Style)this.Resources["_labelPresenter"];
        }

        _grid.DataSource = LimitMonitorSetupRecordPresenterCollection;

      }
      else if (e.NewValue == null)
      {
        _grid.DataSource = null;
        LimitMonitorSetupRecordPresenterCollection = null;
      }
    }

    private LimitMonitorSetupRecordPresenterCollection _limitMonitorSetupRecordPresenterCollection;

    public LimitMonitorSetupRecordPresenterCollection LimitMonitorSetupRecordPresenterCollection
    {
      get { return _limitMonitorSetupRecordPresenterCollection; }
      set { _limitMonitorSetupRecordPresenterCollection = value; }
    }

    private void Cell_PreviewMouseRightButtonDown(object sender, MouseButtonEventArgs e)
    {
      if (_grid.SelectedItems.Records.Count > 1)
        return;
      CellValuePresenter cellValuePresenter = e.Source as CellValuePresenter;
      LimitSetup limitSetup = (cellValuePresenter).Value as LimitSetup;

      ContextMenu contextMenu = new ContextMenu(); 
      {
        contextMenu  =new ContextMenu();
        contextMenu.Items.Add(new MenuItem());
        ((MenuItem)contextMenu.Items[0]).Click += _deleteRecordCM_Click;
        contextMenu.Items.Add(new MenuItem());
        ((MenuItem)contextMenu.Items[1]).Click += _deleteCellCM_Click;
        contextMenu.Items.Add(new MenuItem());
        ((MenuItem)contextMenu.Items[2]).Click += _deleteField_Click;
      }
      cellValuePresenter.ContextMenu = contextMenu;
      {
        //if (showCoontextMenu)
        {
          if (cellValuePresenter.Record != null)
          {
            ((MenuItem)contextMenu.Items[0]).Header = "Delete Record";
            ((MenuItem)contextMenu.Items[0]).Tag = cellValuePresenter.Record;
          }
          if (limitSetup != null)
          {
            ((MenuItem)contextMenu.Items[1]).Header = "Delete :" + limitSetup.ToString();
            ((MenuItem)contextMenu.Items[1]).Tag = limitSetup;
            if (cellValuePresenter.Field != null)
            {
              ((MenuItem)contextMenu.Items[2]).Header = "Delete Field : " + cellValuePresenter.Field.Name;
              ((MenuItem)contextMenu.Items[2]).Tag = cellValuePresenter.Field;
            }
          }

          contextMenu.IsOpen = true;
        }
      }
      //LimitMonitorSetupRecordPresenter presenter =
      //  LimitMonitorSetupRecordPresenterCollection.FindPresenterForLimitSetup(limitSetup);
      //presenter.LimitSetups.Remove(limitSetup);
      //(e.Source as CellValuePresenter).Value = null;
      //XamCurrencyEditor currencyEditor = (e.Source as CellValuePresenter).FindChild<XamCurrencyEditor>("_numberEditor");
      //currencyEditor.Value = null;
    }

    //ContextMenu contextMenu = null;

    private void DataRecordPresenter_PreviewMouseRightButtonDown(object sender, MouseButtonEventArgs e)
    {
      bool showCoontextMenu = false;
      object menuTag = null;
      string message = string.Empty;
      RecordPresenter recordPresenter = e.Source as RecordPresenter;
      if (recordPresenter != null && recordPresenter.Record != null)
      {

        if (_grid.SelectedItems.Records.Count > 1)
        {
          showCoontextMenu = true;
          message = "Delete " + _grid.SelectedItems.Records.Count + " records.";
        }
        else if ((recordPresenter.Record as DataRecord).DataItem is LimitMonitorSetupRecordPresenter)
        {
          showCoontextMenu = true;
          _grid.SelectedItems.Records.Clear();
          LimitMonitorSetupRecordPresenter record = (recordPresenter.Record as DataRecord).DataItem as LimitMonitorSetupRecordPresenter;
          string currency = string.IsNullOrEmpty(record.Currency) ? "All" : record.Currency;
          message = "Delete \"" + currency + "\" record.";
          _grid.SelectedItems.Records.Add(recordPresenter.Record);
        }
      }
      ContextMenu contextMenu = new ContextMenu();
      {
        contextMenu = new ContextMenu();
        contextMenu.Items.Add(new MenuItem());
        ((MenuItem)contextMenu.Items[0]).Click += _deleteRecordCM_Click;
      }
      recordPresenter.ContextMenu = contextMenu;
      //((MenuItem)contextMenu.Items[0]).Visibility = Visibility.Collapsed;
      //((MenuItem)contextMenu.Items[1]).Visibility = Visibility.Collapsed;
      //((MenuItem)contextMenu.Items[2]).Visibility = Visibility.Collapsed;
      if (contextMenu != null)
      {
        if (showCoontextMenu)
        {
          ((MenuItem)contextMenu.Items[0]).Header = message;
          ((MenuItem)contextMenu.Items[0]).Tag = menuTag;
          contextMenu.IsOpen = true;
        }
        else
        {
          //contextMenu.IsOpen = false;
        }
      }
    }

    private void LabelPresenter_PreviewMouseRightButtonDown(object sender, MouseButtonEventArgs e)
    {
      LabelPresenter labelPresenter = sender as LabelPresenter;
      bool showCoontextMenu = false;
      object menuTag = null;
      string message = string.Empty;
      if (labelPresenter != null && labelPresenter.Field != null)
      {
        showCoontextMenu = true;
        message = "Delete : " + labelPresenter.Field.Label;
        menuTag = labelPresenter.Field;
      }
      ContextMenu contextMenu = new ContextMenu();
      {
        contextMenu = new ContextMenu();
        contextMenu.Items.Add(new MenuItem());
        ((MenuItem)contextMenu.Items[0]).Click += _deleteField_Click;
      }
      labelPresenter.ContextMenu = contextMenu;
      if (contextMenu != null)
      {
        if (showCoontextMenu)
        {
          ((MenuItem)contextMenu.Items[0]).Header = message;
          ((MenuItem)contextMenu.Items[0]).Tag = menuTag;
          //((MenuItem)contextMenu.Items[1]).Visibility = System.Windows.Visibility.Collapsed;
          //((MenuItem)contextMenu.Items[2]).Visibility = System.Windows.Visibility.Collapsed;
          contextMenu.IsOpen = true;
        }
        else
        {
          contextMenu.IsOpen = false;
        }
      }
    }

    private void _grid_FieldLayoutInitialized(object sender, Infragistics.Windows.DataPresenter.Events.FieldLayoutInitializedEventArgs e)
    {
      //foreach (Field field in e.FieldLayout.Fields)
      //{
      //  if (field.Label.Equals("Net") || field.Label.Equals("Gross"))
      //  {
      //    field.Settings.EditorType = typeof(XamCurrencyEditor);
      //    Style _style1 = (Style)this.TryFindResource("currencyEditorStyle");
      //    //Setter setter = new Setter(XamCurrencyEditor.MaskProperty, "{}{double:-20.2:c} " + );
      //    //_style1.Setters.Add(setter);
      //    field.Settings.EditorStyle = _style1;

      //    field.Settings.EditAsType = typeof(double);
      //  }
      //}

    }

    private void _deleteField_Click(object sender, RoutedEventArgs e)
    {
      Field field = (e.Source as MenuItem).Tag as Field;
      if (field != null)
      {
        string message = "Deleting : " + field.Name;
        MessageBoxResult boxResult = MessageBoxResult.Yes;
        if (!IsTemplate)
        {
          boxResult = MessageBox.Show(message, "Deleting Limits", MessageBoxButton.YesNo, MessageBoxImage.Question);
        }
        if (boxResult == MessageBoxResult.Yes)
          RemoveField(field);
        return;
      }
    }

    void RemoveField(Field field)
    {
      if (field != null)
      {
        if (field.Tag is Field)
        {
          //its a row 1 field (child field like Net gross)
          Field parentField = field.Tag as Field;
          string maturity = parentField.Name.Equals("All Maturities") ? "" : parentField.Name;
          if (!IsTemplate)
          {
            LimitMonitorDetailSetupModel.LimitSetups = LimitMonitorSetupRecordPresenterCollection.FindLimitSetupsForMaturity(maturity, field.Label.Equals("Net"));
            LimitMonitorDetailSetupModel.ContextDeleteSetupCommand.Execute();
          }
          //else
          {
            LimitMonitorSetupRecordPresenterCollection.RemoveLimitSetupsForMaturity(maturity, field.Label.Equals("Net"));
            _grid.FieldLayouts[0].Fields.Remove(field);
            if (parentField.Tag is IList<Field>)
            {
              IList<Field> childFields = parentField.Tag as IList<Field>;
              if (childFields != null)
              {
                if (childFields.Count == 1)
                {
                  RemoveField(parentField);
                }
                if (childFields.Contains(field))
                {
                  childFields.Remove(field);
                }
              }
            }
          }
        }
        else if (field.Tag is IList<Field>)
        {
          //its a row 0 field (parent field like < 2 maturity)
          IList<Field> childFields = field.Tag as IList<Field>;
          List<LimitSetup> limitSetupsToDelete = new List<LimitSetup>();
          string maturity = field.Name.Equals("All Maturities") ? "" : field.Name;
          if (!IsTemplate)
          {
            foreach (Field deleteField in childFields)
            {
              limitSetupsToDelete.AddRange(LimitMonitorSetupRecordPresenterCollection.FindLimitSetupsForMaturity(maturity, deleteField.Label.Equals("Net")));
            }
            LimitMonitorDetailSetupModel.LimitSetups = limitSetupsToDelete;
            LimitMonitorDetailSetupModel.ContextDeleteSetupCommand.Execute();
          }
          foreach (Field deleteField in childFields)
          {
            LimitMonitorSetupRecordPresenterCollection.RemoveLimitSetupsForMaturity(maturity, deleteField.Label.Equals("Net"));
            _grid.FieldLayouts[0].Fields.Remove(deleteField);
          }
          _grid.FieldLayouts[0].Fields.Remove(field);
        }

      }
    }

    private void _numberEditor_EditModeStarted(object sender, Infragistics.Windows.Editors.Events.EditModeStartedEventArgs e)
    {
      DesSelectAllrecords();
      //XamCurrencyEditor numericEditor = sender as XamCurrencyEditor;
      //if (numericEditor != null)
      //  numericEditor.Background = Brushes.WhiteSmoke;
    }

    private void _numberEditor_EditModeEnded(object sender, Infragistics.Windows.Editors.Events.EditModeEndedEventArgs e)
    {
      DesSelectAllrecords();
      //XamCurrencyEditor numericEditor = sender as XamCurrencyEditor;
      //if (numericEditor != null)
      //  numericEditor.Background = Brushes.Transparent;
    }

    void DesSelectAllrecords()
    {
      if (_grid.SelectedItems != null)
      {
        if (_grid.SelectedItems.Records != null && _grid.SelectedItems.Records.Count > 0)
          _grid.SelectedItems.Records.Clear();
      }
    }

    private void CellValuePresenter_MouseDown(object sender, System.Windows.Input.MouseButtonEventArgs e)
    {
      DesSelectAllrecords();
    }

    private void _deleteRecordCM_Click(object sender, RoutedEventArgs e)
    {
      if (_grid.SelectedItems.Records.Count > 0)
      {
        _grid.ExecuteCommand(DataPresenterCommands.DeleteSelectedDataRecords);
      }
    }

    private void _deleteCellCM_Click(object sender, RoutedEventArgs e)
    {
      LimitSetup limitSetup = (e.Source as MenuItem).Tag as LimitSetup;
      if (limitSetup != null)
      {
        LimitMonitorDetailSetupModel.LimitSetups = new List<LimitSetup>();
        LimitMonitorDetailSetupModel.LimitSetups.Add(limitSetup);
        LimitMonitorDetailSetupModel.ContextDeleteSetupCommand.Execute();
        return;
      }
    }

  }

  public class TestConverter : IValueConverter
  {

    #region IValueConverter Members

    public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
    {
      return value;
    }

    public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
    {
      return value;
    }

    #endregion
  }

  public class LimitAmountCurrencyConvertor : IValueConverter
  {
    #region IValueConverter Members

    public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
    {
      if (value is LimitSetup)
      {
        LimitSetup limitSetup = value as LimitSetup;
        if (limitSetup.Definition.LimitSpecified)
        {
          if (parameter.ToString().Equals("AmountText"))
          {
            return (value as LimitSetup).Definition.Limit.Amount;
          }
          if (parameter.ToString().Equals("CurrencyText"))
          {
            return limitSetup.Definition.Limit.Currency;
          }
        }
      }
      return value;
    }

    public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
    {
      return value;
    }

    #endregion
  }

  public class LimitSetupConvertor : IValueConverter
  {
    public LimitSetupConvertor(string maturity, bool net)
    {
      _maturity = maturity;
      _isnet = net;
    }
    private string _maturity;

    public string Maturity
    {
      get { return _maturity; }
    }
    private bool _isnet;

    public bool IsNet
    {
      get { return _isnet; }
    }

    public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
    {
      if (parameter is DataRecord && value == null)
      {
        DataRecord dr = parameter as DataRecord;
        if (dr.DataItem is LimitMonitorSetupRecordPresenter)
        {
          LimitMonitorSetupRecordPresenter limitMonitorSetupRecordPresenter = dr.DataItem as LimitMonitorSetupRecordPresenter;
          if (limitMonitorSetupRecordPresenter != null)
          {
            if (IsNet)
            {
              foreach (LimitSetup limitSetup in limitMonitorSetupRecordPresenter.LimitSetups_Net)
              {
                if (_maturity.Equals(limitSetup.Definition.Maturity.ToString()) &&
                    _isnet == limitSetup.Definition.Net)
                {
                  return limitSetup;
                }
              }
            }
            else
            {
              foreach (LimitSetup limitSetup in limitMonitorSetupRecordPresenter.LimitSetups_Gross)
              {
                if (_maturity.Equals(limitSetup.Definition.Maturity.ToString()) &&
                    _isnet == limitSetup.Definition.Net)
                {
                  return limitSetup;
                }
              }
            }

          }
        }
      }
      return value;
    }

    public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
    {
      return value;
    }
  }

  //public class CurrencyMaskConvertor : IValueConverter
  //{
  //  public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
  //  {
  //    XamCurrencyEditor xamCurrencyEditor = value as XamCurrencyEditor;
  //    var dgad = xamCurrencyEditor.Host;
  //    //if ((value is  DataRecord) &&  (value as DataRecord).DataItem is LimitMonitorSetupRecordPresenter)
  //    //{
  //    //  DataRecord dr = (value as DataRecord);
  //    //  LimitSetupConvertor limitSetupConvertor = e.Field.Converter as LimitSetupConvertor;
  //    //  LimitMonitorSetupRecordPresenter limitMonitorSetupRecordPresenter = e.Record.DataItem as LimitMonitorSetupRecordPresenter;
  //    //  if (limitSetupConvertor != null)
  //    //  {
  //    //    foreach (LimitSetup limitSetup in limitMonitorSetupRecordPresenter.LimitSetups)
  //    //    {
  //    //      if (limitSetup.Definition.Net == limitSetupConvertor.IsNet && limitSetup.Definition.Maturity.ToString() == limitSetupConvertor.Maturity)
  //    //      {

  //    //      }
  //    //    }
  //    //  }
  //    //}
  //    return value;
  //  }

  //  public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
  //  {

  //    return value;
  //  }
  //}
}
